@@ -1,13 +1,19 @@
 # Provides an example of a self-navigating algorithm which you are under no obligation to use
+# New video tutorials are available at https://www.microprediction.com/python-1 to help you
+# get started running crawlers at www.microprediction.com
+
 from microprediction.writer import MicroWriter
 from microprediction import new_key
 from microconventions import api_url
 import random, time, datetime
-from microprediction.samplers import exponential_bootstrap, approx_mode, _weighted_random_sample
+from microprediction.samplers import approx_mode, _weighted_random_sample, fox_sample
 import pprint
 import numpy as np
 from statistics import median
 import os
+import json
+
+
 
 
 def new_key_if_none(write_key, use_environ=False, difficulty=10):
@@ -136,8 +142,8 @@ class MicroCrawler(MicroWriter):
                :returns            [ float ]    A vector of numbers somewhat indicative of a probability density, of length self.num_predictions
 
         """
-        scenarios = exponential_bootstrap(lagged=lagged_values, num=self.num_predictions, decay=0.01)
-        assert len(scenarios) == self.num_predictions, "Your sammpler should product a vector of length " + str(
+        scenarios = fox_sample(lagged_values=lagged_values, lagged_times=lagged_times, num=self.num_predictions, delay=delay, name=name)
+        assert len(scenarios) == self.num_predictions, "Your sampler should product a vector of length " + str(
             self.num_predictions)
         return sorted(scenarios)
 
@@ -334,7 +340,7 @@ class MicroCrawler(MicroWriter):
         return self.seconds_until_next
 
     def __repr__(self):
-        return {'quietude': self.quietude,
+        return json.dumps({'quietude': self.quietude,
                 'stop_loss': self.stop_loss,
                 'min_lags': self.min_lags,
                 'num_active': len(self.active),
@@ -343,10 +349,10 @@ class MicroCrawler(MicroWriter):
                 'recent_errors': self.get_errors()[-3:],
                 'currently_worst': self.worst_active_horizons(stop_loss=self.stop_loss)[:10],
                 'pending_cancellations': self.pending_cancellations,
-                'upcoming': self.upcoming(num=3, relative=True)}
+                'upcoming': self.upcoming(num=3, relative=True)})
 
     def recent_updates(self):
-        r = self.__repr__()
+        r = json.loads(self.__repr__())
         return dict([(k, v) for k, v in r.items() if ('recent' in k or 'current' in k)])
 
     def withdraw(self, horizon, give_up=False):
