@@ -3,6 +3,7 @@ import requests, time, sys
 from pprint import pprint
 import numpy as np
 import json
+from typing import List, Tuple
 
 # New video tutorials are available at https://www.microprediction.com/python-1 to help you
 # get started reading historical data, and the like.
@@ -76,6 +77,27 @@ class MicroReader(MicroConventions):
         name = self.fix_stream_name(name=name)
         return self.request_get_json(method='lagged',arg=name, data={'count':count-1})
 
+    def get_recent_lagged_values(self, name, seconds:int, count=2000 ):
+        lagged = self.get_lagged(name=name, count=count)
+        t_cutoff = time.time() - seconds
+        lagged_values = [v for (t, v) in lagged if t > t_cutoff]
+        return lagged_values
+
+    def append_chrono(self, name, chrono:List[Tuple], seconds=24 * 60 * 60, count=2000):
+        """ Splice existing collection of historical time-value pairs to recent history stored on server
+
+            chrono:  [(t,v)] history of values, preferably in chronological ordering
+            returns: [(t,v)] extended history to present
+        """
+        chrono = sorted( chrono )
+        lagged = self.get_recent_lagged_values(name=name, seconds=seconds, count=count)
+        if len(chrono):
+            t_cutoff = max([ t for (t,v) in chrono])
+        else:
+            t_cutoff = 0
+        lagged_new = sorted( [ (t,v) for (t,v) in lagged if t>1e-6+t_cutoff ] )
+        return list(chrono)+list(lagged_new)
+
     def get_lagged_values_and_times(self, name, count=1000):
         """ Preferred method """
         name = self.fix_stream_name(name=name)
