@@ -4,6 +4,9 @@ from microconventions.value_conventions import ValueConventions
 import requests, pprint, time, json
 from collections import OrderedDict
 
+# New video tutorials are available at https://www.microprediction.com/python-1 to help you
+# get started creating streams and/or submitting predictions.
+
 
 class MicroWriter(MicroReader):
 
@@ -18,17 +21,27 @@ class MicroWriter(MicroReader):
         self.animal = self.animal_from_key(write_key)  # ... and corresponding spirit animal
 
     def __repr__(self):
-        return {'write_key': self.write_key, "animal": self.animal_from_key(self.write_key)}
+        return json.dumps({'write_key': self.write_key, "animal": self.animal_from_key(self.write_key)})
 
     def get_own_repository(self):
         return self.get_repository(write_key=self.write_key)
 
+    def get_own_predictions(self, name:str, delay:int, strip=True, consolidate=True ):
+        """ Get predictions by others for a stream you own """
+        return self.get_predictions(write_key=self.write_key,name=name, delay=delay, strip=strip, consolidate=consolidate)
+
     def set_repository(self, url):
         """ Tell everyone where your repository is """
         res = requests.put(self.base_url + '/repository/' + self.write_key, params={'url': url})
         if res.status_code == 200:
             return res.json()
 
+    def set_email(self, email:str):
+        """ Tell system, but not anyone else, your email """
+        res = requests.put(self.base_url + '/email/' + self.write_key, params={'email': email})
+        if res.status_code == 200:
+            return res.json()
+
     def delete_repository(self):
         """ Tell everyone where your repository is """
         res = requests.delete(self.base_url + '/repository/' + self.write_key)
@@ -334,6 +347,27 @@ class MicroWriter(MicroReader):
             print('', flush=True)
             raise Exception('Failed to submit')
 
+    def submit_copula(self, name, prctls:[[float]], delay, verbose=True):
+        """ Offers an alternative way to submit to copula streams.
+               prctls: [ [p1,p2,p3] ]   list of percentile vectors in [0,1]^n , where n=2 or 3
+        """
+        assert '~' in name, "This method is intended for implied copula submission"
+        values = [ self.to_zcurve(prctls=prctl) for prctl in prctls ]
+        return self.submit(name=name, values=values, delay=delay, verbose=verbose)
+
+    def submit_zvalues(self, name, zvalues: [[float]], delay, verbose=True):
+        """ Offers an alternative way to submit to copula streams.
+               prctls: [ [z1,z2,z3] ]   list of percentile vectors in [0,1]^n , where n=2 or 3
+        """
+        assert 'z2~' in name or 'z3~' in name, "This method is intended for implied copula submission"
+
+        def squish(zs):
+            prtcls = [ self.normcdf(z) for z in zs ]
+            return self.to_zcurve(prctls=prtcls)
+
+        values = sorted( [squish(zs) for zs in zvalues] )
+        return self.submit(name=name, values=values, delay=delay, verbose=verbose)
+
     def cancel(self, name, delay=None, delays=None):
         """ Send request to cancel scenarios. However predictions won't be deleted immediately.
 
